.. image:: https://travis-ci.org/bobthemighty/punq.svg?branch=master
    :target: https://travis-ci.org/bobthemighty/punq
.. image:: https://img.shields.io/codecov/c/github/bobthemighty/punq.svg?style=flat
    :target https://codecov.io/gh/bobthemighty/punq

Punq
====

An unintrusive library for dependency injection and inversion of control in Python 3.6+
